@@ -4,40 +4,32 @@
 <context>
     <name>SelectWnd</name>
     <message>
-        <location filename="../ui/selectwnd.ui" line="14"/>
+        <location filename="../selectwnd.ui" line="14"/>
         <source>LXQt Mouse Theme Configuration</source>
         <translation>LXQt 鼠标主题配置</translation>
     </message>
     <message>
-        <location filename="../ui/selectwnd.ui" line="20"/>
+        <location filename="../selectwnd.ui" line="20"/>
         <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
-        <translation>选择要使用的游标主题(鼠标放到项目上可以预览)。&lt;b&gt;修改后需要重启LXQt 会话。&lt;/b&gt;：</translation>
+        <translation>选择要使用的指针主题（鼠标放到项目上可以预览），&lt;b&gt;修改后需要重启LXQt 会话&lt;/b&gt;：</translation>
     </message>
     <message>
-        <location filename="../ui/selectwnd.ui" line="81"/>
+        <location filename="../selectwnd.ui" line="81"/>
         <source>&amp;Install New Theme...</source>
         <translation>安装新主题(&amp;I)...</translation>
     </message>
     <message>
-        <source>&amp;Set Theme</source>
-        <translation type="vanished">设置主题(&amp;S)</translation>
-    </message>
-    <message>
-        <location filename="../ui/selectwnd.ui" line="88"/>
+        <location filename="../selectwnd.ui" line="88"/>
         <source>&amp;Remove Theme</source>
         <translation>删除主题(&amp;R)</translation>
     </message>
     <message>
-        <source>&amp;Close</source>
-        <translation type="vanished">&amp;关闭</translation>
-    </message>
-    <message>
-        <location filename="../selectwnd.cpp" line="208"/>
+        <location filename="../selectwnd.cpp" line="212"/>
         <source>XCurTheme error</source>
         <translation>XCurTheme 错误</translation>
     </message>
     <message>
-        <location filename="../selectwnd.cpp" line="209"/>
+        <location filename="../selectwnd.cpp" line="213"/>
         <source>You can&apos;t remove active theme!</source>
         <translation>无法删除使用中的主题！</translation>
     </message>
@@ -45,19 +37,19 @@
 <context>
     <name>WarningLabel</name>
     <message>
-        <location filename="../ui/warninglabel.ui" line="14"/>
+        <location filename="../warninglabel.ui" line="14"/>
         <source>Form</source>
-        <translation type="unfinished"></translation>
+        <translation>形式</translation>
     </message>
     <message>
-        <location filename="../ui/warninglabel.ui" line="44"/>
+        <location filename="../warninglabel.ui" line="44"/>
         <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
-        <translation type="unfinished"></translation>
+        <translation>LXQt 无法找到任何指针主题，将使用默认的 X11 指针主题。LXQt 已找遍下列目录:</translation>
     </message>
     <message>
-        <location filename="../ui/warninglabel.ui" line="54"/>
+        <location filename="../warninglabel.ui" line="54"/>
         <source>Show...</source>
-        <translation type="unfinished"></translation>
+        <translation>显示...</translation>
     </message>
 </context>
 <context>
