@@ -36,34 +36,42 @@ int main(int argn, char* argv[])
     app.setApplicationVersion(VERINFO);
     QCommandLineOption increaseOption(QStringList() << "i" << "icrease",
             app.tr("Increase brightness."));
-    parser.addOption(increaseOption);
     QCommandLineOption decreaseOption(QStringList() << "d" << "decrease",
             app.tr("Decrease brightness."));
-    parser.addOption(decreaseOption);
     QCommandLineOption setOption(QStringList() << "s" << "set",
             app.tr("Set brightness from 1 to 100."), "brightness");
-    parser.addOption(setOption);
+    QCommandLineOption resetGammaOption(QStringList() << "r" << "reset",
+            app.tr("Reset gamma to default value."));
     QCommandLineOption helpOption = parser.addHelpOption();
     parser.addOption(increaseOption);
     parser.addOption(decreaseOption);
     parser.addOption(setOption);
+    parser.addOption(resetGammaOption);
     parser.addOption(helpOption);
     parser.addVersionOption();
 
     parser.process(app);
-    if( parser.isSet(increaseOption) || parser.isSet(decreaseOption) || parser.isSet(setOption) )
+    if( parser.isSet(increaseOption) || parser.isSet(decreaseOption) || parser.isSet(setOption) || parser.isSet(resetGammaOption) )
     {
         XRandrBrightness *brightness = new XRandrBrightness();
-        QList<MonitorInfo> monitors = brightness->getMonitorsInfo();
+        const QList<MonitorInfo> monitors = brightness->getMonitorsInfo();
         QList<MonitorInfo> monitorsChanged;
         float sign = parser.isSet(decreaseOption)?-1.0:1.0;
         double brightness_value = parser.value(setOption).toFloat();
         brightness_value = qMin( qMax(brightness_value, 0.0), 100.0 ) / 100.0;
         if(!parser.value(setOption).isEmpty())
             sign = 0.0;
-        foreach(MonitorInfo monitor, monitors)
+
+        for(MonitorInfo monitor : monitors)
         {
-            if( monitor.isBacklightSupported() )
+            if(parser.isSet(resetGammaOption))
+            {
+                monitor.setBrightness(1.0);
+                monitorsChanged.append(monitor);
+                continue;
+            }
+
+            if(monitor.isBacklightSupported() )
             {
                 long backlight = ( monitor.backlight() + sign*(monitor.backlightMax()/50 + 1) )*qAbs(sign) + brightness_value*monitor.backlightMax();
                 if(backlight<monitor.backlightMax() && backlight>0)
