@@ -6,70 +6,70 @@
     <message>
         <location filename="../keyboardconfig.ui" line="14"/>
         <source>Form</source>
-        <translation type="unfinished"></translation>
+        <translation>Dialoogvenster</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="20"/>
         <source>Cursor flash time:</source>
-        <translation type="unfinished"></translation>
+        <translation>Knippertijd voor aanwijzer:</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="27"/>
         <source>&lt;b&gt;Keyboard&lt;/b&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;b&gt;Toetsenbord&lt;/b&gt;</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="34"/>
         <source>Beep when there is an error of keyboard input</source>
-        <translation type="unfinished">Piep wanneer er een toetsenbordinvoerfout optreedt</translation>
+        <translation>Piep wanneer er een toetsenbordinvoerfout plaatsvindt</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="41"/>
         <source> ms</source>
-        <translation type="unfinished"></translation>
+        <translation> ms</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="51"/>
         <source>Character Repeat</source>
-        <translation type="unfinished">Tekenherhaling</translation>
+        <translation>Tekenherhaling</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="79"/>
         <location filename="../keyboardconfig.ui" line="143"/>
         <source>Long</source>
-        <translation type="unfinished">Lang</translation>
+        <translation>Lang</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="108"/>
         <source>Repeat delay:</source>
-        <translation type="unfinished">Herhalingsvertraging:</translation>
+        <translation>Herhaalvertraging:</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="115"/>
         <location filename="../keyboardconfig.ui" line="136"/>
         <source>Short</source>
-        <translation type="unfinished">Kort</translation>
+        <translation>Kort</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="122"/>
         <source>Repeat interval:</source>
-        <translation type="unfinished">Herhalingstussenpoze:</translation>
+        <translation>Herhaalsnelheid:</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="129"/>
         <source>Type in the following box to test your keyboard settings</source>
-        <translation type="unfinished">Tik iets in het volgende vak om uw toetsenbordinstellingen uit te proberen</translation>
+        <translation>Tik in het volgende veld om uw toetsenbordinstellingen uit te proberen</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="150"/>
         <location filename="../keyboardconfig.ui" line="157"/>
         <source>0</source>
-        <translation type="unfinished">0</translation>
+        <translation>0</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="167"/>
         <source>Turn on NumLock after login</source>
-        <translation type="unfinished"></translation>
+        <translation>NumLock inschakelen na aanmelden</translation>
     </message>
 </context>
 <context>
@@ -77,136 +77,57 @@
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="20"/>
         <source>&lt;b&gt;Keyboard Layout&lt;/b&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;b&gt;Toetsenbordindeling&lt;/b&gt;</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="48"/>
         <source>Layout</source>
-        <translation type="unfinished"></translation>
+        <translation>Indeling</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="53"/>
         <source>Variant</source>
-        <translation type="unfinished"></translation>
+        <translation>Variant</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="63"/>
         <source>&amp;Add</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Toevoegen</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="70"/>
         <source>&amp;Remove</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Verwijderen</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="77"/>
-        <source>up</source>
-        <translation type="unfinished"></translation>
+        <source>Up</source>
+        <translation>Omhoog</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="84"/>
-        <source>down</source>
-        <translation type="unfinished"></translation>
+        <source>Down</source>
+        <translation>Omlaag</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="108"/>
         <source>Keyboard model:</source>
-        <translation type="unfinished"></translation>
+        <translation>Toetsenbordmodel:</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="122"/>
         <source>Keys to change layout:</source>
-        <translation type="unfinished"></translation>
+        <translation>Toetsen om de indeling te wijzigen:</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="133"/>
         <source>None</source>
-        <translation type="unfinished"></translation>
+        <translation>Geen</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="141"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note&lt;/span&gt;: If you are using an &lt;span style=&quot; font-weight:600;&quot;&gt;input method&lt;/span&gt;, such as IBus, uim, fcitx, or gcin, the settings here &lt;span style=&quot; font-weight:600;&quot;&gt;might not work&lt;/span&gt; because they are overridden by the input methods.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
-<context>
-    <name>MainDialog</name>
-    <message>
-        <source>Input Device Preferences</source>
-        <translation type="vanished">Voorkeuren van invoerapparaat</translation>
-    </message>
-    <message>
-        <source>Motion</source>
-        <translation type="vanished">Beweging</translation>
-    </message>
-    <message>
-        <source>High</source>
-        <translation type="vanished">Hoog</translation>
-    </message>
-    <message>
-        <source>Fast</source>
-        <translation type="vanished">Snel</translation>
-    </message>
-    <message>
-        <source>Sensitivity:</source>
-        <translation type="vanished">Gevoeligheid:</translation>
-    </message>
-    <message>
-        <source>Low</source>
-        <translation type="vanished">Laag</translation>
-    </message>
-    <message>
-        <source>Acceleration:</source>
-        <translation type="vanished">Versnelling:</translation>
-    </message>
-    <message>
-        <source>Slow</source>
-        <translation type="vanished">Langzaam</translation>
-    </message>
-    <message>
-        <source>0</source>
-        <translation type="vanished">0</translation>
-    </message>
-    <message>
-        <source>Left handed (Swap left and right mouse buttons)</source>
-        <translation type="vanished">Linkshandig (wissel linkse en rechtse muisknoppen om)</translation>
-    </message>
-    <message>
-        <source>Mouse</source>
-        <translation type="vanished">Muis</translation>
-    </message>
-    <message>
-        <source>Character Repeat</source>
-        <translation type="vanished">Tekenherhaling</translation>
-    </message>
-    <message>
-        <source>Long</source>
-        <translation type="vanished">Lang</translation>
-    </message>
-    <message>
-        <source>Repeat delay:</source>
-        <translation type="vanished">Herhalingsvertraging:</translation>
-    </message>
-    <message>
-        <source>Short</source>
-        <translation type="vanished">Kort</translation>
-    </message>
-    <message>
-        <source>Repeat interval:</source>
-        <translation type="vanished">Herhalingstussenpoze:</translation>
-    </message>
-    <message>
-        <source>Type in the following box to test your keyboard settings</source>
-        <translation type="vanished">Tik iets in het volgende vak om uw toetsenbordinstellingen uit te proberen</translation>
-    </message>
-    <message>
-        <source>Beep when there is an error of keyboard input</source>
-        <translation type="vanished">Piep wanneer er een toetsenbordinvoerfout optreedt</translation>
-    </message>
-    <message>
-        <source>Keyboard</source>
-        <translation type="vanished">Toetsenbord</translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Let op&lt;/span&gt;: indien u een &lt;span style=&quot; font-weight:600;&quot;&gt;invoermethode&lt;/span&gt; gebruikt zoals IBus, uim, fcitx of gcin, zullen de instellingen hier &lt;span style=&quot; font-weight:600;&quot;&gt;mogelijkerwijs niet werken&lt;/span&gt;, omdat ze worden tenietgedaan door de invoermethoden.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
 </context>
 <context>
@@ -214,106 +135,106 @@
     <message>
         <location filename="../mouseconfig.ui" line="14"/>
         <source>Form</source>
-        <translation type="unfinished"></translation>
+        <translation>Dialoogvenster</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="23"/>
         <source>&lt;b&gt;Mouse&lt;/b&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;b&gt;Muis&lt;/b&gt;</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="30"/>
         <source>Motion</source>
-        <translation type="unfinished">Beweging</translation>
+        <translation>Beweging</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="36"/>
         <source>High</source>
-        <translation type="unfinished">Hoog</translation>
+        <translation>Hoog</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="43"/>
         <source>Fast</source>
-        <translation type="unfinished">Snel</translation>
+        <translation>Snel</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="50"/>
         <source>Sensitivity:</source>
-        <translation type="unfinished">Gevoeligheid:</translation>
+        <translation>Gevoeligheid:</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="57"/>
         <source>Low</source>
-        <translation type="unfinished">Laag</translation>
+        <translation>Laag</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="83"/>
         <source>Acceleration:</source>
-        <translation type="unfinished">Versnelling:</translation>
+        <translation>Versnelling:</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="109"/>
         <source>Slow</source>
-        <translation type="unfinished">Langzaam</translation>
+        <translation>Langzaam</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="116"/>
         <location filename="../mouseconfig.ui" line="123"/>
         <source>0</source>
-        <translation type="unfinished">0</translation>
+        <translation>0</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="133"/>
         <source>Double click interval:</source>
-        <translation type="unfinished"></translation>
+        <translation>Tussenpoze voor dubbelklikken:</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="140"/>
         <source> ms</source>
-        <translation type="unfinished"></translation>
+        <translation> ms</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="150"/>
         <source>Wheel scroll lines:</source>
-        <translation type="unfinished"></translation>
+        <translation>Te schuiven regels voor muiswiel:</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="160"/>
         <source>Left handed (Swap left and right mouse buttons)</source>
-        <translation type="unfinished">Linkshandig (wissel linkse en rechtse muisknoppen om)</translation>
+        <translation>Linkshandige bediening (linker- und rechtermuistoetsen omwisselen)</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="167"/>
         <source>Single click to activate items</source>
-        <translation type="unfinished"></translation>
+        <translation>Enkele klik om elementen te activeren</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
-    <message>
-        <location filename="../lxqt-config-input.cpp" line="34"/>
-        <source>Keyboard and Mouse Settings</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../lxqt-config-input.cpp" line="39"/>
-        <source>Mouse</source>
-        <translation type="unfinished">Muis</translation>
-    </message>
-    <message>
-        <location filename="../lxqt-config-input.cpp" line="44"/>
-        <source>Cursor</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../lxqt-config-input.cpp" line="47"/>
-        <source>Keyboard</source>
-        <translation type="unfinished">Toetsenbord</translation>
-    </message>
     <message>
         <location filename="../lxqt-config-input.cpp" line="51"/>
+        <source>Keyboard and Mouse Settings</source>
+        <translation>Instellingen van toetsenbord en muis</translation>
+    </message>
+    <message>
+        <location filename="../lxqt-config-input.cpp" line="56"/>
+        <source>Mouse</source>
+        <translation>Muis</translation>
+    </message>
+    <message>
+        <location filename="../lxqt-config-input.cpp" line="61"/>
+        <source>Cursor</source>
+        <translation>Aanwijzer</translation>
+    </message>
+    <message>
+        <location filename="../lxqt-config-input.cpp" line="64"/>
+        <source>Keyboard</source>
+        <translation>Toetsenbord</translation>
+    </message>
+    <message>
+        <location filename="../lxqt-config-input.cpp" line="68"/>
         <source>Keyboard Layout</source>
-        <translation type="unfinished"></translation>
+        <translation>Toetsenbordindeling</translation>
     </message>
 </context>
 <context>
@@ -321,17 +242,17 @@
     <message>
         <location filename="../selectkeyboardlayoutdialog.ui" line="14"/>
         <source>Select a keyboard layout</source>
-        <translation type="unfinished"></translation>
+        <translation>Kies een toetsenbordindeling</translation>
     </message>
     <message>
         <location filename="../selectkeyboardlayoutdialog.ui" line="20"/>
         <source>Keyboard layout</source>
-        <translation type="unfinished"></translation>
+        <translation>Toetsenbordindeling</translation>
     </message>
     <message>
         <location filename="../selectkeyboardlayoutdialog.ui" line="27"/>
         <source>Variant</source>
-        <translation type="unfinished"></translation>
+        <translation>Variant</translation>
     </message>
 </context>
 </TS>
